@@ -3,7 +3,8 @@
  */
 module.exports.find = function (obj, fun) {
     for (var i = 0, r; i < obj.length; i++) {
-        if (r = fun.call(obj, obj[i])) { return r; }
+        r = fun.call(obj, obj[i]);
+        if (r) { return r; }
     }
     return null;
 };
