@@ -6,7 +6,7 @@ tree.Comment = function Comment(value, silent) {
 };
 
 tree.Comment.prototype = {
-    toString: function(env) {
+    toString: function() {
         return '<!--' + this.value + '-->';
     },
     'ev': function() { return this; }
