@@ -1,5 +1,7 @@
 (function(tree) {
 
+var _ = require('lodash');
+
 tree.Expression = function Expression(value) {
     this.value = value;
 };
@@ -17,9 +19,20 @@ tree.Expression.prototype = {
     },
 
     toString: function(env) {
-        return this.value.map(function(e) {
-            return e.toString(env);
-        }).join(' ');
+        var containsObj = false,
+            mappedVal = this.value.map(function(e) {
+                var result = e.toString(env);
+
+                if (_.isObject(result)) {
+                    containsObj = true;
+                }
+                return result;
+            });
+
+        if (containsObj) {
+            return mappedVal;
+        }
+        return mappedVal.join(' ');
     }
 };
 
