@@ -8,13 +8,14 @@ tree.Quoted.prototype = {
     is: 'string',
 
     toString: function(quotes) {
-        var xmlvalue = this.value
+        var escapedValue = this.value
             .replace(/&/g, '&amp;')
-            .replace(/\'/g, '&apos;')
+        var xmlvalue = escapedValue
+            .replace(/\'/g, '\\\'')
             .replace(/\"/g, '&quot;')
             .replace(/</g, '&lt;')
             .replace(/\>/g, '&gt;');
-        return (quotes === true) ? "'" + xmlvalue + "'" : this.value;
+        return (quotes === true) ? "'" + xmlvalue + "'" : escapedValue;
     },
 
     'ev': function() {
