@@ -1,5 +1,7 @@
 (function(tree) {
 
+var _ = require('lodash');
+
 tree.Value = function Value(value) {
     this.value = value;
 };
@@ -16,9 +18,20 @@ tree.Value.prototype = {
         }
     },
     toString: function(env, selector, sep, format) {
-        return this.value.map(function(e) {
-            return e.toString(env, format);
-        }).join(sep || ', ');
+        var containsObj = false,
+            mappedVal = this.value.map(function(e) {
+                var result = e.toString(env, format);
+
+                if (_.isObject(result)) {
+                    containsObj = true;
+                }
+                return result;
+            });
+
+        if (containsObj) {
+            return _.flatten(mappedVal);
+        }
+        return mappedVal.join(sep || ', ');
     },
     clone: function() {
         var obj = Object.create(tree.Value.prototype);
