@@ -6,19 +6,21 @@ require('../lib/carto/tree/filter');
 
 describe('Field', function() {
     describe('basic functionality', function() {
+        var ref = new tree.Reference();
+        ref.setVersion(ref.getLatest());
         it('should be constructed', function() {
             var f = new tree.Filter(new tree.Field('foo'), '=', new tree.Dimension(1));
             assert.ok(f);
         });
         it('can be evaluated', function() {
             var f = new tree.Filter(new tree.Field('foo'), '=', new tree.Dimension(1));
-            f.ev({});
+            f.ev({ ref: ref });
             assert.ok(f);
         });
-        it('yields xml', function() {
+        it('yields object', function() {
             var f = new tree.Filter(new tree.Field('foo'), '=', new tree.Dimension(1));
-            f.ev({});
-            assert.equal(f.toXML({}), '[foo] = 1');
+            f.ev({ ref: ref });
+            assert.equal(f.toObject({ ref: ref }), '[foo] = 1');
         });
     });
 });
