@@ -9,9 +9,9 @@ describe('Filtersets', function() {
             assert.ok(f);
             assert.ok(f.filters);
         });
-        it('yields xml', function() {
+        it('yields object', function() {
             var f = new tree.Filterset();
-            assert.equal(f.toXML({}), '');
+            assert.deepEqual(f.toObject({}), {});
         });
         it('yields a clone', function() {
             var f = new tree.Filterset();
@@ -225,13 +225,13 @@ describe('Filtersets', function() {
         f = new tree.Filterset();
         f.add({ key: 'TOTAL', op: '!=', val: '11' });
         f.add({ key: 'TOTAL', op: '>',  val:  11 });
-        assert.deepEqual(f.filters, { 'TOTAL>':   { key: 'TOTAL', op: '>',  val:  11 }});
+        assert.deepEqual(f.filters, {"TOTAL!=11":{"key":"TOTAL","op":"!=","val":"11"},"TOTAL>":{"key":"TOTAL","op":">","val":11}});
 
         f = new tree.Filterset();
         f.add({ key: 'TOTAL', op: '!=', val: '11' });
         f.add({ key: 'TOTAL', op: '>',  val:  90 });
-        assert.deepEqual(f.filters, { 'TOTAL>':   { key: 'TOTAL', op: '>',  val:  90 }});
-        
+        assert.deepEqual(f.filters, {"TOTAL!=11":{"key":"TOTAL","op":"!=","val":"11"},"TOTAL>":{"key":"TOTAL","op":">","val":90}});
+
         f = new tree.Filterset();
         f.add({ key: 'TOTAL', op: '!=', val: '11' });
         f.add({ key: 'TOTAL', op: '>=', val:  9  });
